@@ -24,17 +24,16 @@ import pytest
 from openlineage.client.event_v2 import Job, Run, RunEvent, RunState
 from openlineage.client.facet_v2 import job_type_job, parent_run
 
-from airflow.exceptions import AirflowOptionalProviderFeatureException
 from airflow.providers.common.compat.openlineage.facet import (
     ErrorMessageRunFacet,
     ExternalQueryRunFacet,
     SQLJobFacet,
 )
+from airflow.providers.common.compat.sdk import AirflowOptionalProviderFeatureException
 from airflow.providers.databricks.hooks.databricks import DatabricksHook
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook
 from airflow.providers.databricks.utils.openlineage import (
     _create_ol_event_pair,
-    _get_ol_run_id,
     _get_parent_run_facet,
     _get_queries_details_from_databricks,
     _process_data_from_api,
@@ -46,40 +45,9 @@ from airflow.utils import timezone
 from airflow.utils.state import TaskInstanceState
 
 
-def test_get_ol_run_id_ti_success():
-    logical_date = timezone.datetime(2025, 1, 1)
-    mock_ti = mock.MagicMock(
-        dag_id="dag_id",
-        task_id="task_id",
-        map_index=1,
-        try_number=1,
-        logical_date=logical_date,
-        state=TaskInstanceState.SUCCESS,
-    )
-    mock_ti.get_template_context.return_value = {"dag_run": mock.MagicMock(logical_date=logical_date)}
-
-    result = _get_ol_run_id(mock_ti)
-    assert result == "01941f29-7c00-7087-8906-40e512c257bd"
-
-
-def test_get_ol_run_id_ti_failed():
-    logical_date = timezone.datetime(2025, 1, 1)
-    mock_ti = mock.MagicMock(
-        dag_id="dag_id",
-        task_id="task_id",
-        map_index=1,
-        try_number=1,
-        logical_date=logical_date,
-        state=TaskInstanceState.FAILED,
-    )
-    mock_ti.get_template_context.return_value = {"dag_run": mock.MagicMock(logical_date=logical_date)}
-
-    result = _get_ol_run_id(mock_ti)
-    assert result == "01941f29-7c00-7087-8906-40e512c257bd"
-
-
 def test_get_parent_run_facet():
     logical_date = timezone.datetime(2025, 1, 1)
+    dr = mock.MagicMock(logical_date=logical_date, clear_number=0)
     mock_ti = mock.MagicMock(
         dag_id="dag_id",
         task_id="task_id",
@@ -87,14 +55,18 @@ def test_get_parent_run_facet():
         try_number=1,
         logical_date=logical_date,
         state=TaskInstanceState.SUCCESS,
+        dag_run=dr,
     )
-    mock_ti.get_template_context.return_value = {"dag_run": mock.MagicMock(logical_date=logical_date)}
+    mock_ti.get_template_context.return_value = {"dag_run": dr}
 
     result = _get_parent_run_facet(mock_ti)
 
     assert result.run.runId == "01941f29-7c00-7087-8906-40e512c257bd"
     assert result.job.namespace == namespace()
     assert result.job.name == "dag_id.task_id"
+    assert result.root.run.runId == "01941f29-7c00-743e-b109-28b18d0a19c5"
+    assert result.root.job.namespace == namespace()
+    assert result.root.job.name == "dag_id"
 
 
 def test_run_api_call_success():
@@ -121,9 +93,8 @@ def test_run_api_call_request_error():
     mock_response.status_code = 200
 
     with mock.patch("requests.get", side_effect=RuntimeError("request error")):
-        result = _run_api_call(mock_hook, ["123"])
-
-    assert result == []
+        with pytest.raises(RuntimeError):
+            _run_api_call(mock_hook, ["123"])
 
 
 def test_run_api_call_token_error():
@@ -135,9 +106,8 @@ def test_run_api_call_token_error():
     mock_response.status_code = 200
 
     with mock.patch("requests.get", return_value=mock_response):
-        result = _run_api_call(mock_hook, ["123"])
-
-    assert result == []
+        with pytest.raises(RuntimeError):
+            _run_api_call(mock_hook, ["123"])
 
 
 def test_process_data_from_api():
@@ -194,6 +164,18 @@ def test_get_queries_details_from_databricks_empty_query_ids():
     assert details == {}
 
 
+@mock.patch("airflow.providers.databricks.utils.openlineage._run_api_call")
+def test_get_queries_details_from_databricks_error(mock_api_call):
+    mock_api_call.side_effect = RuntimeError("Token error")
+
+    hook = DatabricksSqlHook()
+    query_ids = ["ABC"]
+
+    details = _get_queries_details_from_databricks(hook, query_ids)
+    mock_api_call.assert_called_once_with(hook=hook, query_ids=query_ids)
+    assert details == {}
+
+
 @mock.patch("airflow.providers.databricks.utils.openlineage._run_api_call")
 def test_get_queries_details_from_databricks(mock_api_call):
     hook = DatabricksSqlHook()
@@ -273,15 +255,14 @@ def test_create_ol_event_pair_success(mock_generate_uuid, is_successful):
     assert start_event.job == end_event.job
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
-def test_emit_openlineage_events_for_databricks_queries(mock_now, mock_generate_uuid, mock_version):
+def test_emit_openlineage_events_for_databricks_queries(mock_generate_uuid, mock_version, time_machine):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     query_ids = ["query1", "query2", "query3"]
     original_query_ids = copy.deepcopy(query_ids)
@@ -511,17 +492,16 @@ def test_emit_openlineage_events_for_databricks_queries(mock_now, mock_generate_
         assert fake_adapter.emit.call_args_list == expected_calls
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
 def test_emit_openlineage_events_for_databricks_queries_without_metadata(
-    mock_now, mock_generate_uuid, mock_version
+    mock_generate_uuid, mock_version, time_machine
 ):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     query_ids = ["query1"]
     original_query_ids = copy.deepcopy(query_ids)
@@ -630,17 +610,16 @@ def test_emit_openlineage_events_for_databricks_queries_without_metadata(
         assert fake_adapter.emit.call_args_list == expected_calls
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
 def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_ids(
-    mock_now, mock_generate_uuid, mock_version
+    mock_generate_uuid, mock_version, time_machine
 ):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     query_ids = ["query1"]
     hook = mock.MagicMock()
@@ -753,17 +732,16 @@ def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_i
 @mock.patch(
     "airflow.providers.openlineage.sqlparser.SQLParser.create_namespace", return_value="databricks_ns"
 )
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
 def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_ids_and_namespace(
-    mock_now, mock_generate_uuid, mock_version, mock_parser
+    mock_generate_uuid, mock_version, mock_parser, time_machine
 ):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     query_ids = ["query1"]
     hook = mock.MagicMock()
@@ -872,17 +850,16 @@ def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_i
         assert fake_adapter.emit.call_args_list == expected_calls
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
 def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_ids_and_namespace_raw_ns(
-    mock_now, mock_generate_uuid, mock_version
+    mock_generate_uuid, mock_version, time_machine
 ):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     query_ids = ["query1"]
     hook = DatabricksHook()
@@ -992,17 +969,16 @@ def test_emit_openlineage_events_for_databricks_queries_without_explicit_query_i
         assert fake_adapter.emit.call_args_list == expected_calls
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 @mock.patch("openlineage.client.uuid.generate_new_uuid")
-@mock.patch("airflow.utils.timezone.utcnow")
 def test_emit_openlineage_events_for_databricks_queries_ith_query_ids_and_hook_query_ids(
-    mock_now, mock_generate_uuid, mock_version
+    mock_generate_uuid, mock_version, time_machine
 ):
     fake_uuid = "01958e68-03a2-79e3-9ae9-26865cc40e2f"
     mock_generate_uuid.return_value = fake_uuid
 
     default_event_time = timezone.datetime(2025, 1, 5, 0, 0, 0)
-    mock_now.return_value = default_event_time
+    time_machine.move_to(default_event_time, tick=False)
 
     hook = DatabricksSqlHook()
     hook.query_ids = ["query2", "query3"]
@@ -1113,7 +1089,7 @@ def test_emit_openlineage_events_for_databricks_queries_ith_query_ids_and_hook_q
         assert fake_adapter.emit.call_args_list == expected_calls
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 def test_emit_openlineage_events_for_databricks_queries_missing_query_ids_and_hook(mock_version):
     query_ids = []
     original_query_ids = copy.deepcopy(query_ids)
@@ -1138,7 +1114,7 @@ def test_emit_openlineage_events_for_databricks_queries_missing_query_ids_and_ho
         fake_adapter.emit.assert_not_called()  # No events should be emitted
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 def test_emit_openlineage_events_for_databricks_queries_missing_query_namespace_and_hook(mock_version):
     query_ids = ["1", "2"]
     original_query_ids = copy.deepcopy(query_ids)
@@ -1164,7 +1140,7 @@ def test_emit_openlineage_events_for_databricks_queries_missing_query_namespace_
         fake_adapter.emit.assert_not_called()  # No events should be emitted
 
 
-@mock.patch("importlib.metadata.version", return_value="2.3.0")
+@mock.patch("importlib.metadata.version", return_value="3.0.0")
 def test_emit_openlineage_events_for_databricks_queries_missing_hook_and_query_for_extra_metadata_true(
     mock_version,
 ):
@@ -1209,7 +1185,7 @@ def test_emit_openlineage_events_with_old_openlineage_provider(mock_version):
         return_value=fake_listener,
     ):
         expected_err = (
-            "OpenLineage provider version `1.99.0` is lower than required `2.3.0`, "
+            "OpenLineage provider version `1.99.0` is lower than required `2.5.0`, "
             "skipping function `emit_openlineage_events_for_databricks_queries` execution"
         )
 
